@@ -43,6 +43,7 @@ Usage::
         GetOpsSummaryPaginator,
         GetParameterHistoryPaginator,
         GetParametersByPathPaginator,
+        GetResourcePoliciesPaginator,
         ListAssociationVersionsPaginator,
         ListAssociationsPaginator,
         ListCommandInvocationsPaginator,
@@ -94,6 +95,7 @@ Usage::
     get_ops_summary_paginator: GetOpsSummaryPaginator = client.get_paginator("get_ops_summary")
     get_parameter_history_paginator: GetParameterHistoryPaginator = client.get_paginator("get_parameter_history")
     get_parameters_by_path_paginator: GetParametersByPathPaginator = client.get_paginator("get_parameters_by_path")
+    get_resource_policies_paginator: GetResourcePoliciesPaginator = client.get_paginator("get_resource_policies")
     list_association_versions_paginator: ListAssociationVersionsPaginator = client.get_paginator("list_association_versions")
     list_associations_paginator: ListAssociationsPaginator = client.get_paginator("list_associations")
     list_command_invocations_paginator: ListCommandInvocationsPaginator = client.get_paginator("list_command_invocations")
@@ -163,6 +165,7 @@ from .type_defs import (
     GetOpsSummaryResultTypeDef,
     GetParameterHistoryResultTypeDef,
     GetParametersByPathResultTypeDef,
+    GetResourcePoliciesResponseTypeDef,
     InstanceInformationFilterTypeDef,
     InstanceInformationStringFilterTypeDef,
     InstancePatchStateFilterTypeDef,
@@ -233,6 +236,7 @@ __all__ = (
     "GetOpsSummaryPaginator",
     "GetParameterHistoryPaginator",
     "GetParametersByPathPaginator",
+    "GetResourcePoliciesPaginator",
     "ListAssociationVersionsPaginator",
     "ListAssociationsPaginator",
     "ListCommandInvocationsPaginator",
@@ -871,6 +875,21 @@ class GetParametersByPathPaginator(Paginator):
         """
 
 
+class GetResourcePoliciesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetResourcePolicies)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getresourcepoliciespaginator)
+    """
+
+    def paginate(
+        self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[GetResourcePoliciesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.GetResourcePolicies.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/paginators/#getresourcepoliciespaginator)
+        """
+
+
 class ListAssociationVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Paginator.ListAssociationVersions)
